@@ -1,7 +1,6 @@
 #' @export
-type_sum.vctrs_unspecified <- function(x) {
-  # FIXME: Remove when vec_ptype_abbr.vctrs_unspecified() becomes available
-  "???"
+pillar_shaft.vctrs_unspecified <- function(x, ...) {
+  new_pillar_shaft_simple(rep(".", vctrs::vec_size(x)), align = "right")
 }
 
 #' @export
@@ -17,7 +16,7 @@ type_sum.vctrs_vctr <- function(x) {
 
 #' @export
 pillar_shaft.vctrs_list_of <- function(x, ...) {
-  out <- paste0("[", map_chr(x, pillar::dim_desc), "]")
+  out <- style_subtle(map_chr(x, size_sum))
 
   new_pillar_shaft_simple(out, align = "right")
 }
