@@ -49,7 +49,7 @@ local_colors <- function(.local_envir = parent.frame()) {
   # We run this first, so this will run last by withr, to restore the
   # original options.
   withr::local_options(
-    list(crayon.enabled = TRUE, crayon.colors = 16L, cli.num_colors = 16L),
+    list(crayon.enabled = TRUE, cli.num_colors = 16L),
     .local_envir = .local_envir
   )
 
